==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageS3CloudFrontFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageRegistryConfigStorageS3CloudFrontFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontFluent<A>{
  public ImageRegistryConfigStorageS3CloudFrontFluentImpl() {
  }
  public ImageRegistryConfigStorageS3CloudFrontFluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront instance) {
    this.withBaseURL(instance.getBaseURL()); 
    this.withDuration(instance.getDuration()); 
    this.withKeypairID(instance.getKeypairID()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String baseURL;
  private io.fabric8.kubernetes.api.model.Duration duration;
  private java.lang.String keypairID;
  private io.fabric8.kubernetes.api.model.SecretKeySelector privateKey;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBaseURL() {
    return this.baseURL;
  }
  public A withBaseURL(java.lang.String baseURL) {
    this.baseURL=baseURL; return (A) this;
  }
  public java.lang.Boolean hasBaseURL() {
    return this.baseURL != null;
  }
  
  /**
   * Method is deprecated. use withBaseURL instead.
   */
  @java.lang.Deprecated
  public A withNewBaseURL(java.lang.String arg0) {
    return (A)withBaseURL(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.Duration getDuration() {
    return this.duration;
  }
  public A withDuration(io.fabric8.kubernetes.api.model.Duration duration) {
    this.duration=duration; return (A) this;
  }
  public java.lang.Boolean hasDuration() {
    return this.duration != null;
  }
  public java.lang.String getKeypairID() {
    return this.keypairID;
  }
  public A withKeypairID(java.lang.String keypairID) {
    this.keypairID=keypairID; return (A) this;
  }
  public java.lang.Boolean hasKeypairID() {
    return this.keypairID != null;
  }
  
  /**
   * Method is deprecated. use withKeypairID instead.
   */
  @java.lang.Deprecated
  public A withNewKeypairID(java.lang.String arg0) {
    return (A)withKeypairID(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getPrivateKey() {
    return this.privateKey;
  }
  public A withPrivateKey(io.fabric8.kubernetes.api.model.SecretKeySelector privateKey) {
    this.privateKey=privateKey; return (A) this;
  }
  public java.lang.Boolean hasPrivateKey() {
    return this.privateKey != null;
  }
  public A withNewPrivateKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withPrivateKey(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigStorageS3CloudFrontFluentImpl that = (ImageRegistryConfigStorageS3CloudFrontFluentImpl) o;
    if (baseURL != null ? !baseURL.equals(that.baseURL) :that.baseURL != null) return false;
    if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
    if (keypairID != null ? !keypairID.equals(that.keypairID) :that.keypairID != null) return false;
    if (privateKey != null ? !privateKey.equals(that.privateKey) :that.privateKey != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseURL,  duration,  keypairID,  privateKey,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageS3CloudFrontFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageRegistryConfigStorageS3CloudFrontFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontFluent<A>{
  public ImageRegistryConfigStorageS3CloudFrontFluentImpl() {
  }
  public ImageRegistryConfigStorageS3CloudFrontFluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront instance) {
    this.withBaseURL(instance.getBaseURL()); 
    this.withDuration(instance.getDuration()); 
    this.withKeypairID(instance.getKeypairID()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String baseURL;
  private io.fabric8.kubernetes.api.model.Duration duration;
  private java.lang.String keypairID;
  private io.fabric8.kubernetes.api.model.SecretKeySelector privateKey;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBaseURL() {
    return this.baseURL;
  }
  public A withBaseURL(java.lang.String baseURL) {
    this.baseURL=baseURL; return (A) this;
  }
  public java.lang.Boolean hasBaseURL() {
    return this.baseURL != null;
  }
  
  /**
   * Method is deprecated. use withBaseURL instead.
   */
  @java.lang.Deprecated
  public A withNewBaseURL(java.lang.String arg0) {
    return (A)withBaseURL(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.Duration getDuration() {
    return this.duration;
  }
  public A withDuration(io.fabric8.kubernetes.api.model.Duration duration) {
    this.duration=duration; return (A) this;
  }
  public java.lang.Boolean hasDuration() {
    return this.duration != null;
  }
  public java.lang.String getKeypairID() {
    return this.keypairID;
  }
  public A withKeypairID(java.lang.String keypairID) {
    this.keypairID=keypairID; return (A) this;
  }
  public java.lang.Boolean hasKeypairID() {
    return this.keypairID != null;
  }
  
  /**
   * Method is deprecated. use withKeypairID instead.
   */
  @java.lang.Deprecated
  public A withNewKeypairID(java.lang.String arg0) {
    return (A)withKeypairID(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getPrivateKey() {
    return this.privateKey;
  }
  public A withPrivateKey(io.fabric8.kubernetes.api.model.SecretKeySelector privateKey) {
    this.privateKey=privateKey; return (A) this;
  }
  public java.lang.Boolean hasPrivateKey() {
    return this.privateKey != null;
  }
  public A withNewPrivateKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withPrivateKey(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigStorageS3CloudFrontFluentImpl that = (ImageRegistryConfigStorageS3CloudFrontFluentImpl) o;
    if (baseURL != null ? !baseURL.equals(that.baseURL) :that.baseURL != null) return false;
    if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
    if (keypairID != null ? !keypairID.equals(that.keypairID) :that.keypairID != null) return false;
    if (privateKey != null ? !privateKey.equals(that.privateKey) :that.privateKey != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseURL,  duration,  keypairID,  privateKey,  additionalProperties,  super.hashCode());
  }
  
}
